Pinned Tweet
Кажется, мы все немного подзабыли,
что в любой сложной ситуации важно оставаться Человеком.
Иван Афанасьев retweeted
I wrote a new data structure for binary search that is up to 15x faster than std::lower_bound.
en.algorithmica.org/hpc/data…
Иван Афанасьев retweeted
Kid just asked me whether there was a negative zero.
I knew this day would come but I wasn't quite ready to have The Talk about IEEE 754 quite yet.
Иван Афанасьев retweeted
I needed to help my students visualize struct layout and padding bytes, so I created a C++20 pretty printer (see picture).
Available below, use/improve it as you like!
gcc.godbolt.org/z/aG5dedPbn
#cpp #cpp20 #metaprogramming #reflection
Иван Афанасьев retweeted
We are excited to announce that our CMake book is officially going open source! You can access it here: ow.ly/5hmM50EGEgC
#Cmake #Opensource #developers
I'm going to present a long story about short commit to libc++ which makes to_string up to 20x times faster #cpprussia. It covers improvements from high level optimizations to assembler tuning.
Special thanks to @tsafin who agreed to moderate the talk.
cppconf-moscow.ru/2020/msk/t…
Иван Афанасьев retweeted
Орден Мрачного Хлебальника (ещё разок, теперь акварельный)
#kosmonozhka
Иван Афанасьев retweeted
Reduced compile times when using fmt/format.h and some common API functions from 0.6s to 0.3s with the default settings (-O0) or from 2.3s to 0.3s with -O2. Thanks GitHub user alex3d for the idea. github.com/fmtlib/fmt/issues… #programming
Иван Афанасьев retweeted
Немногие знают, что дифф на -5 строк в Питере ощущается как дифф на -40 строк в Сибири, а всё из-за влажности.
Иван Афанасьев retweeted
Cursed code
“abcde” + “´”
and results string size.
In C++, Python and Swift
C++ wandbox.org/permlink/NSyZffZ…
Python wandbox.org/permlink/plRKc5P…
Swift wandbox.org/permlink/F3IPnr6…
#Programming
Иван Афанасьев retweeted
nice visualization of some traffic problems I was thinking about some days ago (not my viz), maybe something for @simongerman600























